From 78137929e639d174fdc3d4fe8dcf643321b7dfb2 Mon Sep 17 00:00:00 2001
From: Eugen Rochko <eugen@zeonfederated.com>
Date: Tue, 22 Mar 2016 09:03:03 +0100
Subject: [PATCH] Fix #20, reblogs in Atom should be formatted correctly now

---
 app/helpers/atom_builder_helper.rb | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/app/helpers/atom_builder_helper.rb b/app/helpers/atom_builder_helper.rb
index b9eb79fbd9..132ea15738 100644
--- a/app/helpers/atom_builder_helper.rb
+++ b/app/helpers/atom_builder_helper.rb
@@ -190,9 +190,13 @@ module AtomBuilderHelper
           link_avatar      xml, stream_entry.target
         end
 
         # Statuses have content
         if [:note, :comment].include? stream_entry.target.object_type
           content xml, conditionally_formatted(stream_entry.target)
+
+          author(xml) do
+            include_author xml, stream_entry.target.account
+          end
         end
       end
     end
@@ -190,9 +190,13 @@ module AtomBuilderHelper
         end
 
-        # Statuses have content
+        # Statuses have content and author
         if [:note, :comment].include? stream_entry.target.object_type
           content xml, conditionally_formatted(stream_entry.target)